require('dotenv').config();
const express = require('express');
const axios = require('axios');
const path = require('path');

const app = express();
const PORT = process.env.PORT || 80;

// Serve static files from the 'public' directory
app.use(express.static('public'));

// Serve the main HTML page
app.get('/', (req, res) => {
    res.sendFile(path.join(__dirname, 'index.html'));
});

app.get('/predictions', async (req, res) => {
    const options = {
        method: 'GET',
        url: 'https://football-prediction-api.p.rapidapi.com/api/v2/predictions',
        params: { market: 'classic', iso_date: '2024-08-21' }, // Adjust iso_date as needed
        headers: {
            'X-RapidAPI-Key': process.env.RAPIDAPI_KEY,
            'X-RapidAPI-Host': 'football-prediction-api.p.rapidapi.com'
        }
    };

    try {
        const response = await axios.request(options);
        const predictions = response.data.data;
        res.json(predictions);
    } catch (error) {
        console.error('Error fetching predictions:', error.response ? error.response.data : error.message);
        res.status(500).send('Error fetching predictions');
    }
});